PALM-meteo: palmmeteo/library.py File Reference

PALM-meteo

Classes | Namespaces | Functions | Variables
library.py File Reference

## Classes
class | palmmeteo.library.PalmPhysics
class | palmmeteo.library.UnitConverter
class | palmmeteo.library.InputUnitsInfo
class | palmmeteo.library.LoadedQuantity
class | palmmeteo.library.QuantityCalculator
class | palmmeteo.library.TriRegridder
class | palmmeteo.library.LatLonRegularGrid

## Namespaces
namespace | palmmeteo
namespace | palmmeteo.library

## Functions
def | palmmeteo.library.barycentric (tri, pt, isimp)
def | palmmeteo.library.verify_palm_hinterp (regridder, lats, lons)
def | palmmeteo.library.parse_linspace (space, name, maxerr)

## Variables
| palmmeteo.library.utc = datetime.timezone.utc
| palmmeteo.library.utcdefault = lambda dt: dt.replace(tzinfo=utc) if dt.tzinfo is None else dt